// NearestRandomPoint.cpp : This file contains the 'main' function. Program execution begins and ends there.
//

//#include "pch.h"
#include <iostream>
#include <cstdio>
#include <vector>
#include <string>
#include <cassert>
#include <cstdlib>
#include <algorithm>

//#include <bits/stdc++.h>

using namespace std;

const long long MAXNUM = 8000000000000000000ll;
const int MAXN = 200500;
const int MAXCOORD = (1 << 18);

long long sum(long long x, long long y) {
	long long ans = x + y;
	x = abs(x);
	y = abs(y);
	assert(MAXNUM - y >= x);
	return ans;
}

long long subtract(long long x, long long y) {
	long long ans = x - y;
	sum(x, -y);
	return ans;
}

long long mul(long long x, long long y) {
	if (!x || !y)
		return 0;
	long long ans = x * y;
	assert(MAXNUM / abs(x) >= abs(y));
	return ans;
}

struct Rational {
	long long nom = 0, denom = 0;
};

Rational norm(Rational r) {
	if (r.denom < 0)
		return Rational{ -r.nom, -r.denom };
	else
		return r;
}

bool operator < (Rational r1, Rational r2) {
	//assert(r1.denom > 0 && r2.denom > 0);
	r1 = norm(r1);
	r2 = norm(r2);
	return mul(r1.nom, r2.denom) < mul(r2.nom, r1.denom);
}

bool operator <= (Rational r1, Rational r2) {
	return !(r2 < r1);
}

Rational operator - (Rational r) {
	return Rational{ -r.nom, r.denom };
}

Rational operator + (Rational r1, Rational r2) {
	return Rational{ sum(mul(r1.nom, r2.denom), mul(r1.denom, r2.nom)), mul(r1.denom, r2.denom) };
}

Rational operator - (Rational r1, Rational r2) {
	return Rational{ subtract(mul(r1.nom, r2.denom), mul(r1.denom, r2.nom)), mul(r1.denom, r2.denom) };
}

Rational operator * (Rational r, long long x) {
	return Rational{ mul(r.nom, x), r.denom };
}

Rational operator * (Rational r1, Rational r2) {
	return Rational{ mul(r1.nom, r2.nom), mul(r1.denom, r2.denom) };
}

Rational operator / (Rational r1, Rational r2) {
	return Rational{ mul(r1.nom, r2.denom), mul(r1.denom, r2.nom) };
}

long long floor(Rational v) {
	long long ans = v.nom / v.denom;
	if (v.nom % v.denom == 0)
		return ans;
	if (v < Rational{ ans, 1 })
		return ans - 1;
	else
		return ans;
}

long long ceil(Rational v) {
	long long ans = v.nom / v.denom;
	if (v.nom % v.denom == 0)
		return ans;
	if (Rational{ ans, 1 } < v)
		return ans + 1;
	else
		return ans;
}

struct Point {
	Rational x, y;
};

Point operator + (Point p1, Point p2) {
	return Point{ p1.x + p2.x, p1.y + p2.y };
}

Point operator - (Point p1, Point p2) {
	return Point{ p1.x - p2.x, p1.y - p2.y };
}

Point operator * (Point p, Rational v) {
	return Point{ p.x * v, p.y * v };
}

struct Line {
	Point p{ Rational{0, 1}, Rational{0, 1} }, v{ Rational{0, 1}, Rational{0, 1} };

	bool isEmpty() const {
		return v.x.nom == 0 && v.y.nom == 0;
	}

	bool isVertical() const {
		return v.x.nom == 0;
	}

	Rational getY(Rational x) {
		return p.y + v.y * (x - p.x) / v.x;
	}

	Rational getY(long long x) {
		return getY(Rational{ x, 1 });
	}
};

int readInt() {
	int v;
	scanf("%d", &v);
	return v;
}

struct Tree {
	Line* tree;

	Tree()
	{
		tree = new Line[MAXCOORD * 4];
		for (int i = 0; i < MAXCOORD * 4; ++i)
			tree[i] = Line{ Point{Rational{0, 1}, Rational{0, 1}}, Point{Rational{1, 1}, Rational{0, 1}} };
	}

	~Tree() {
		delete[] tree;
	}

	void setLineLocal(int v, int lx, int rx, Line line) {
		Line vline = tree[v];
		Rational val1l = line.getY(lx);
		Rational val1r = line.getY(rx-1);
		Rational val2l = vline.getY(lx);
		Rational val2r = vline.getY(rx - 1);

		if (val1l <= val2l && val1r <= val2r)
			return;
		if (val2l <= val1l && val2r <= val1r) {
			tree[v] = line;
			return;
		}

		if (val1l < val2l) {
			swap(line, vline);
			swap(val1l, val2l);
			swap(val1r, val2r);
		}

		int midx = (lx + rx) / 2;
		Rational val1mid = line.getY(midx);
		Rational val2mid = vline.getY(midx);
		if (val2mid <= val1mid) {
			tree[v] = line;
			setLineLocal(v * 2 + 1, midx, rx, vline);
		}
		else {
			tree[v] = vline;
			setLineLocal(v * 2, lx, midx, line);
		}
	}

	void setLine(Line l) {
		setLineLocal(1, 0, MAXCOORD, l);
	}

	Rational getY(int x) {
		assert(0 <= x && x < MAXCOORD);
		Rational y = tree[1].getY(x);
		int l = 0;
		int r = MAXCOORD;
		int v = 1;
		while (l + 1 < r) {
			int mid = (l + r) / 2;
			if (x < mid) {
				r = mid;
				v = v * 2;
			}
			else {
				l = mid;
				v = v * 2 + 1;
			}
			y = max(y, tree[v].getY(x));
		}
		return y;
	}
};

Point ps[MAXN];

vector<Rational> getYsDown(const vector<Line> &lines, int lx, int rx) {
	Tree tree;
	for (Line l : lines)
		tree.setLine(l);
	vector<Rational> ys;
	for (int x = lx; x <= rx; ++x)
		ys.push_back(tree.getY(x));
	return ys;
}

vector<Rational> getYsUp(vector<Line> lines, int lx, int rx, int Y) {
	Rational rY{ Y, 1 };
	for (int i = 0; i < (int)lines.size(); ++i) {
		lines[i].p.y = rY - lines[i].p.y;
		lines[i].v.y = -lines[i].v.y;
		//lines[i].v.x = -lines[i].v.x;
	}

	vector<Rational> ys = getYsDown(lines, lx, rx);
	for (int i = 0; i < (int)ys.size(); ++i)
		ys[i] = rY - ys[i];
	return ys;
}

long long findGcd(long long x, long long y) {
	x = abs(x);
	y = abs(y);
	while (y) {
		x %= y;
		swap(x, y);
	}
	return x;
}

int main()
{
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	int X, Y, n;
	X = readInt();
	Y = readInt();
	n = readInt();

	for (int i = 0; i < n; ++i) {
		ps[i].x = Rational{readInt(), 1};
		ps[i].y = Rational{readInt(), 1};
	}

	int lx = 0;
	int rx = X;

	vector<Line> linesDown, linesUp;
	linesDown.push_back(Line{ Point{Rational{0, 1}, Rational{0, 1}}, Point{Rational{1, 1}, Rational{0, 1}} });
	linesUp.push_back(Line{ Point{Rational{Y, 1}, Rational{Y, 1}}, Point{Rational{-1, 1}, Rational{0, 1}} });

	for (int i = 1; i < n; ++i)
		if (ps[i].y.nom == ps[0].y.nom) {
			Rational x = (ps[0].x + ps[i].x) / Rational{ 2, 1 };
			if (ps[0].x < ps[i].x)
				rx = min((long long)rx, floor(x));
			else
				lx = max((long long)lx, ceil(x));
		}
		else {
			Point v = ps[i] - ps[0];
			v = Point{ -v.y, v.x };
			Point p = (ps[i] + ps[0]) * Rational{ 1, 2 };
			
			if (ps[i].y < ps[0].y)
				linesDown.push_back(Line{ p, v });
			else
				linesUp.push_back(Line{ p, v });
		}
	
	vector<Rational> ysDown = getYsDown(linesDown, 0, X);
	vector<Rational> ysUp = getYsUp(linesUp, 0, X, Y);

	/*
	for (int i = 0; i <= X; ++i)
		cerr << ysDown[i].nom << ' ' << ysDown[i].denom << endl;
	for (int i = 0; i <= X; ++i)
		cerr << ysUp[i].nom << ' ' << ysUp[i].denom << endl;
	*/

	long long ans = 0;
	for (int x = lx; x <= rx; ++x) {
		long long lv = ceil(ysDown[x]);
		long long rv = floor(ysUp[x]);
		ans += max((long long)0, rv - lv + 1);
	}

    cout << ans << "\n";
	//long long s = X + 1;
	//s *= Y + 1;
	//long long g = findGcd(ans, s);
	//cout << ans/g << "/" <<  s / g << "\n";
	return 0;
}

// Run program: Ctrl + F5 or Debug > Start Without Debugging menu
// Debug program: F5 or Debug > Start Debugging menu

// Tips for Getting Started: 
//   1. Use the Solution Explorer window to add/manage files
//   2. Use the Team Explorer window to connect to source control
//   3. Use the Output window to see build output and other messages
//   4. Use the Error List window to view errors
//   5. Go to Project > Add New Item to create new code files, or Project > Add Existing Item to add existing code files to the project
//   6. In the future, to open this project again, go to File > Open > Project and select the .sln file
