#include <iostream>
#include <vector>
#include <map>
#include "testlib.h"

using namespace std;

int n, m;
vector <vector <char> > room;
vector <vector <vector <int> > > dist_to_wall;

struct point {
	int x, y;
	point(int x = 0, int y = 0) : x(x), y(y) {}
	point operator + (point p) {
		return point(x + p.x, y + p.y);
	}
	point operator * (int q) {
		return point(x * q, y * q);
	}
	bool operator != (const point p) const {
		return x != p.x || y != p.y;
	}
	bool operator == (const point p) const {
		return x == p.x && y == p.y;
	}
	void read() {
		x = inf.readInt() - 1;
		y = inf.readInt() - 1;
	}
	void write() {
		cout << x + 1 << " " << y + 1 << endl;
	}
	bool in() {
		return 0 <= x && x < n && 0 <= y && y < m;
	}
	bool is(char ch) {
		return in() && room[x][y] == ch;
	}
	int &get(vector <vector <int> > &v) {
		return v[x][y];
	}
};

point d[] = {{-1, 0}, {0, -1}, {0, 1}, {1, 0}};

int build_dtw(point v, int dir) {
	if (v.get(dist_to_wall[dir]) != -1) {
		return v.get(dist_to_wall[dir]);
	}
	if (!v.is('W')) {
		v.get(dist_to_wall[dir]) = build_dtw(v + d[dir], dir) + 1;
		return v.get(dist_to_wall[dir]);
	} else {
		return -1;
	}
}

map <char, int> d_num;
map <char, int> p_num;
point start, finish;

inline int readAndCheckAnswer(InStream& in) {
	point pos = start;
	vector <point> portals(2, {-1, -1});
	vector <int> portals_dir(2, -1);
	
	int cnt_p = in.readInt(-1, n * m);
	int cnt_m = in.readInt(-1, n * m * 2);
	
	if (cnt_p == -1 || cnt_m == -1) {
		return -1;
	}
	
	int cnt = 0;

	for (int i = 0; i < cnt_p + cnt_m; ++i) {
		string s = in.readToken("[OBM][LRUD]");
		char type = s[0];
		int dir = d_num[s[1]];
		if (type == 'M') {
			point n_pos = pos + d[dir];
			if (n_pos.is('.')) {
				pos = n_pos;
				continue;
			}
			if (n_pos.is('G')) {
				in.quitf(_wa, "Participant wants to go into the glass wall. dir=%c, pos=(%d, %d), step=%d", s[1], pos.x + 1, pos.y + 1, i + 1);
			}
			
			int id;
			for (id = 0; id < 2; ++id) {
				if (portals[id] == pos && portals_dir[id] == dir) {
					break;
				}
			}
			if (id == 2) {
				in.quitf(_wa, "Participant wants to go into the normal wall without any portal. dir=%c, pos=(%d, %d), step=%d", s[1], pos.x + 1, pos.y + 1, i + 1);
			}
			if (portals_dir[1 - id] == -1) {
				in.quitf(_wa, "Participant wants to go into the portal, but did not make second portal. dir=%c, pos=(%d, %d), step=%d", s[1], pos.x + 1, pos.y + 1, i + 1);
			}
			if (portals[1 - id].is('G')) {
				in.quitf(_wa, "Participant make the portal right in front of glass wall and want to go it. dir=%c, pos=(%d, %d), step=%d", s[1], pos.x + 1, pos.y + 1, i + 1);
			}
			pos = portals[1 - id];
		} else {
			++cnt;
			int id = p_num[type];
			point to = pos + d[dir] * pos.get(dist_to_wall[dir]);
			if (portals[1 - id] == to && portals_dir[1 - id] == dir) {
				continue; //Participant want to make portal in the place of second portal
			}
			portals[id] = to;
			portals_dir[id] = dir;
		}
	}

	if (cnt != cnt_p) {
		in.quitf(_wa, "The number of portals does not match what the participant counted");
	}
	if (pos != finish) {
		in.quitf(_wa, "Participant not in finish position");
	}
	return cnt;
}

int main(int argc, char *argv[]) {
    registerTestlibCmd(argc, argv);	

    n = inf.readInt();
    m = inf.readInt();
    inf.readEoln();
    room.assign(n, vector <char> (m));
    for (int i = 0; i < n; ++i) {
    	for (int j = 0; j < m; ++j) {
    		room[i][j] = inf.readChar();
    	}
    	inf.readEoln();
    }
    start.read();
    finish.read();

    d_num['U'] = 0;
    d_num['L'] = 1;
    d_num['R'] = 2;
    d_num['D'] = 3;
    p_num['O'] = 0;
    p_num['B'] = 1;

    dist_to_wall.assign(4, vector <vector <int> > (n, vector <int> (m, -1)));
    for (int i = 0; i < n; ++i) {
		for (int j = 0; j < m; ++j) {
			for (int dir = 0; dir < 4; ++dir) {
				build_dtw({i, j}, dir);
			}
		}
	}

    int ja = readAndCheckAnswer(ans);
    int pa = readAndCheckAnswer(ouf);

    if (ja == -1 || pa == -1) {
    	if (ja == -1 && pa == -1) {
			quitf(_ok, "There is no way");    		
    	}
    	if (pa == -1) {
    		quitf(_wa, "Jury found a way, but participant did not");
    	}
    	quitf(_fail, "Participant found a way, but jury did not");
    }
    if (ja < pa) {
    	quitf(_wa, "Jury has better way than participant");
    }
    if (ja > pa) {
    	quitf(_fail, "Participant has better way than jury");
    }
    quitf(_ok, "answer is %d", ja);
}