#include <iostream>
#include <vector>
#include <queue>
#include <algorithm>
#include <string>

using namespace std;

const int INF = 1e9;

vector <vector <char> > room;
vector <vector <vector <int> > > dist_to_wall;
vector <vector <int> > color;
vector <vector <int> > used;
int n, m;

struct point {
	int x, y;
	point(int x = 0, int y = 0) : x(x), y(y) {}
	point operator + (point p) {
		return point(x + p.x, y + p.y);
	}
	point operator - (point p) {
		return point(x - p.x, y - p.y);
	}
	point operator * (int q) {
		return point(x * q, y * q);
	}
	bool operator != (const point p) const {
		return x != p.x || y != p.y;
	}
	bool operator == (const point p) const {
		return x == p.x && y == p.y;
	}
	bool in() {
		return 0 <= x && x < n && 0 <= y && y < m;	
	}
	bool is(char ch) {
		return in() && room[x][y] == ch;
	}
	int sum() {
		return x + y;
	}
	void read() {
		cin >> x >> y;
		--x;
		--y;
	}
	void write() {
		cout << x << " " << y << endl;
	}
	int &get(vector <vector <int> > &v) {
		return v[x][y];
	}
};

point d[] = {{-1, 0}, {0, -1}, {0, 1}, {1, 0}};
string d_name[] = {"U", "L", "R", "D"};

int build_dtw(point v, int dir) {
	if (v.get(dist_to_wall[dir]) != -1) {
		return v.get(dist_to_wall[dir]);
	}
	if (!v.is('W')) {
		v.get(dist_to_wall[dir]) = build_dtw(v + d[dir], dir) + 1;
		return v.get(dist_to_wall[dir]);
	} else {
		return -1;
	}
}

void dfs(point v, int col) {
	v.get(color) = col;
	for (int i = 0; i < 4; ++i) {
		point nv = v + d[i];
		if (nv.is('.') && nv.get(color) == -1) {
			dfs(nv, col);
		}
	}
}

point find_wall(point v, vector <vector <int> > &used) {
	v.get(used) = 1;
	for (int dir = 0; dir < 4; ++dir) {
		point nv = v + d[dir];
		if (nv.is('W')) {
			return v;
		}
		if (nv.is('.') && !nv.get(used)) {
			point res = find_wall(nv, used);
			if (res != point(-1, -1)) {
				return res;
			}
		}
	}
	return {-1, -1};
}

void add(vector <string> &a, vector <string> &b) {
	reverse(b.begin(), b.end());
	for (auto &s: b) {
		a.push_back(s);
	}
	b.clear();
}



string p_name[] = {"O", "B"};
int p_number = 0;
int new_dir = -1;
point pos;

point make_portal_to(point v, int col, int number, vector <string> &ans) {
	v.get(used) = number;
	for (int dir = 0; dir < 4; ++dir) {
		point to = v + d[dir] * v.get(dist_to_wall[dir]);
		if (to.is('.') && to.get(color) == col) {
			ans.push_back(p_name[p_number] + d_name[dir]);
			pos = v;
			new_dir = dir;
			p_number ^= 1;
			return to;
		}
	}
	for (int dir = 0; dir < 4; ++dir) {
		point nv = v + d[dir];
		if (nv.is('.') && nv.get(used) != number) {
			point p = make_portal_to(nv, col, number, ans);
			if (p != point(-1, -1)) {
				ans.push_back("M" + d_name[dir]);
				return p;
			}
		}
	}
	return {-1, -1};
}

bool move_to(point v, point to, int number, vector <string> &ans) {
	v.get(used) = number;
	if (v == to) {
		pos = to;
		return 1;
	}
	for (int dir = 0; dir < 4; ++dir) {
		point nv = v + d[dir];
		if (nv.is('.') && nv.get(used) != number) {
			if (move_to(nv, to, number, ans)) {
				ans.push_back("M" + d_name[dir]);
				return 1;
			}
		}
	}
	return 0;
}

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);

	cin >> n >> m;
	room.assign(n, vector <char> (m));
	dist_to_wall.assign(4, vector <vector <int> > (n, vector <int> (m, -1)));
	color.assign(n, vector <int> (m, -1));

	for (auto &v: room) {
		for (auto &i: v) {
			cin >> i;
		}
	}
	point start, finish;
	start.read();
	finish.read();

	for (int i = 0; i < n; ++i) {
		for (int j = 0; j < m; ++j) {
			for (int dir = 0; dir < 4; ++dir) {
				build_dtw({i, j}, dir);
			}
		}
	}

	int cnt = 0;
	for (int i = 0; i < n; ++i) {
		for (int j = 0; j < m; ++j) {
			if (room[i][j] == '.' && color[i][j] == -1) {
				dfs({i, j}, cnt);
				++cnt;
			}
		}
	}

	vector <vector <int> > gr(cnt);
	for (int i = 0; i < n; ++i) {
		for (int j = 0; j < m; ++j) {
			if (color[i][j] == -1) {
				continue;
			}
			for (int dir = 0; dir < 4; ++dir) {
				point to = point(i, j) + d[dir] * dist_to_wall[dir][i][j];
				if (to.is('.')) {
					gr[color[i][j]].push_back(to.get(color));
				}
			}
		}
	}

	vector <int> dist(cnt, INF);
	vector <int> par(cnt, -1);
	dist[start.get(color)] = 0;

	queue <int> q;
	q.push(start.get(color));

	while (!q.empty()) {
		int v = q.front();
		q.pop();
		for (auto u: gr[v]) {
			if (dist[u] > dist[v] + 1) {
				dist[u] = dist[v] + 1;
				par[u] = v;
				q.push(u);
			}
		}
	}

	vector <int> zero(m, 0);
	used.assign(n, zero);


	point wall = find_wall(start, used);
	if (dist[finish.get(color)] == INF || (wall == point(-1, -1) &&
										   dist[finish.get(color)] != 0)) {
		cout << "-1 -1" << endl;
		return 0;
	}
	
	vector <int> path_c;
	int f = finish.get(color);
	do {
		path_c.push_back(f);
		f = par[f];
	} while (f != -1);
	reverse(path_c.begin(), path_c.end());


	used.assign(n, zero);


	point actual_portal(-1, -1);
	int actual_dir = -1;
	pos = start;
	vector <string> ans;
	vector <string> local_ans;
	for (int i = 0; i + 1 < path_c.size(); ++i) {
		point new_portal = make_portal_to(pos, path_c[i + 1], 1, local_ans);
		add(ans, local_ans);
		if (actual_dir != -1) {
			move_to(pos, actual_portal, 2, local_ans);
			add(ans, local_ans);
			ans.push_back("M" + d_name[actual_dir]);
			
			pos = new_portal;
			actual_portal = new_portal;
			actual_dir = new_dir;
		} else {
			move_to(pos, wall, 2, local_ans);
			add(ans, local_ans);
			for (int dir = 0; dir < 4; ++dir) {
				point p = pos + d[dir];
				if (p.is('W')) {
					ans.push_back(p_name[p_number] + d_name[dir]);
					ans.push_back("M" + d_name[dir]);
					break;		
				}
			}
			pos = new_portal;
			actual_portal = new_portal;
			actual_dir = new_dir;
		}
	}
	move_to(pos, finish, 1, local_ans);
	add(ans, local_ans);

	int d = dist[finish.get(color)];
	d += d != 0;
	cout << d << " " << ans.size() - d << "\n";
	for (auto &i: ans) {
		cout << i << "\n";
	}
	return 0;
}